==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/km-KH/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'ព័​ត៍​មាន​បន្ថែម',

    'audit_help' => 'Checking this box will edit the asset record to reflect this new location. Leaving it unchecked will simply note the location in the audit log.<br><br>Note that if this asset is checked out, it will not change the location of the person, asset or location it is checked out to.',

    'assets' => 'ទ្រព្យសកម្មគឺជាធាតុដែលតាមដានដោយលេខស៊េរី ឬស្លាកទ្រព្យសម្បត្តិ។ ពួកវាមានទំនោរទៅជាធាតុមានតម្លៃខ្ពស់ជាង ដែលការកំណត់អត្តសញ្ញាណធាតុជាក់លាក់មួយមានសារៈសំខាន់។',

    'categories' => 'ប្រភេទជួយអ្នករៀបចំធាតុរបស់អ្នក។ ប្រភេទឧទាហរណ៍មួយចំនួនអាចជា &quot;កុំព្យូទ័រលើតុ&quot; &quot;កុំព្យូទ័រយួរដៃ&quot; &quot;ទូរស័ព្ទចល័ត&quot; &quot;ថេប្លេត&quot; ជាដើម។ ប៉ុន្តែអ្នកអាចប្រើប្រភេទតាមវិធីណាក៏ដោយដែលសមហេតុផលសម្រាប់អ្នក។',

    'accessories' => 'គ្រឿងបន្ថែមគឺជាអ្វីដែលអ្នកផ្តល់ដល់អ្នកប្រើប្រាស់ ប៉ុន្តែវាមិនមានលេខសៀរៀល (ឬអ្នកមិនខ្វល់អំពីការតាមដានពួកវាតែមួយទេ)។ ឧទាហរណ៍ កណ្តុរកុំព្យូទ័រ ឬក្តារចុច។',

    'companies'     => 'ក្រុមហ៊ុនអាចត្រូវបានប្រើជាវាលកំណត់អត្តសញ្ញាណសាមញ្ញ ឬអាចត្រូវបានប្រើដើម្បីកំណត់លទ្ធភាពមើលឃើញនៃទ្រព្យសម្បត្តិ អ្នកប្រើប្រាស់។ល។ ប្រសិនបើការគាំទ្រក្រុមហ៊ុនពេញលេញត្រូវបានបើកនៅក្នុងការកំណត់អ្នកគ្រប់គ្រងរបស់អ្នក។',

    'components'    => 'Components គឺជាធាតុដែលជាផ្នែកមួយនៃទ្រព្យសកម្ម ឧទាហរណ៍ HDD, RAM ។ល។',

    'consumables'   => 'សម្ភារៈប្រើប្រាស់គឺជារបស់ដែលទិញ ដែលនឹងប្រើប្រាស់លើសម៉ោង។ ឧទាហរណ៍ ទឹកថ្នាំម៉ាស៊ីនបោះពុម្ព ឬក្រដាសចម្លង។',

    'depreciations' => 'អ្នកអាចកំណត់ការរំលោះទ្រព្យសកម្ម ដើម្បីរំលោះទ្រព្យសកម្មដោយផ្អែកលើការរំលោះបន្ទាត់ត្រង់។',
    
    'empty_file'    => 'អ្នកនាំចូលរកឃើញថាឯកសារនេះទទេ។'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/km-KH/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'ព័​ត៍​មាន​បន្ថែម',

    'audit_help' => 'ការធីកប្រអប់នេះនឹងកែសម្រួលកំណត់ត្រាទ្រព្យសម្បត្តិដើម្បីឆ្លុះបញ្ចាំងពីទីតាំងថ្មីនេះ។ ការទុកវាចោលដោយមិនធីកនឹងកត់សម្គាល់ទីតាំងនៅក្នុងកំណត់ហេតុសវនកម្ម។<br><br>ចំណាំថាប្រសិនបើទ្រព្យសកម្មនេះត្រូវបាន checked out វានឹងមិនផ្លាស់ប្តូរទីតាំងរបស់មនុស្ស ទ្រព្យសម្បត្តិ ឬទីតាំងដែលវាត្រូវបាន checked out ទៅ.',

    'assets' => 'ទ្រព្យសកម្មគឺជាធាតុដែលតាមដានដោយលេខស៊េរី ឬស្លាកទ្រព្យសម្បត្តិ។ ពួកវាមានទំនោរទៅជាធាតុមានតម្លៃខ្ពស់ជាង ដែលការកំណត់អត្តសញ្ញាណធាតុជាក់លាក់មួយមានសារៈសំខាន់។',

    'categories' => 'ប្រភេទជួយអ្នករៀបចំធាតុរបស់អ្នក។ ប្រភេទឧទាហរណ៍មួយចំនួនអាចជា &quot;កុំព្យូទ័រលើតុ&quot; &quot;កុំព្យូទ័រយួរដៃ&quot; &quot;ទូរស័ព្ទចល័ត&quot; &quot;ថេប្លេត&quot; ជាដើម។ ប៉ុន្តែអ្នកអាចប្រើប្រភេទតាមវិធីណាក៏ដោយដែលសមហេតុផលសម្រាប់អ្នក។',

    'accessories' => 'គ្រឿងបន្ថែមគឺជាអ្វីដែលអ្នកផ្តល់ដល់អ្នកប្រើប្រាស់ ប៉ុន្តែវាមិនមានលេខសៀរៀល (ឬអ្នកមិនខ្វល់អំពីការតាមដានពួកវាតែមួយទេ)។ ឧទាហរណ៍ កណ្តុរកុំព្យូទ័រ ឬក្តារចុច។',

    'companies'     => 'ក្រុមហ៊ុនអាចត្រូវបានប្រើជាវាលកំណត់អត្តសញ្ញាណសាមញ្ញ ឬអាចត្រូវបានប្រើដើម្បីកំណត់លទ្ធភាពមើលឃើញនៃទ្រព្យសម្បត្តិ អ្នកប្រើប្រាស់។ល។ ប្រសិនបើការគាំទ្រក្រុមហ៊ុនពេញលេញត្រូវបានបើកនៅក្នុងការកំណត់អ្នកគ្រប់គ្រងរបស់អ្នក។',

    'components'    => 'Components គឺជាធាតុដែលជាផ្នែកមួយនៃទ្រព្យសកម្ម ឧទាហរណ៍ HDD, RAM ។ល។',

    'consumables'   => 'សម្ភារៈប្រើប្រាស់គឺជារបស់ដែលទិញ ដែលនឹងប្រើប្រាស់លើសម៉ោង។ ឧទាហរណ៍ ទឹកថ្នាំម៉ាស៊ីនបោះពុម្ព ឬក្រដាសចម្លង។',

    'depreciations' => 'អ្នកអាចកំណត់ការរំលោះទ្រព្យសកម្ម ដើម្បីរំលោះទ្រព្យសកម្មដោយផ្អែកលើការរំលោះបន្ទាត់ត្រង់។',
    
    'empty_file'    => 'អ្នកនាំចូលរកឃើញថាឯកសារនេះទទេ។'
];
